@@ -219,3 +219,26 @@ def configure(config):
     path = os.path.join(os.path.dirname(__file__), 'reports', filename)
     if html_report_conf.gen_report:
         config.option.htmlpath = path
+
+
+def configure_base(config):
+    """Sets the launch name based on the marker selected."""
+    global if_reportportal
+    if_reportportal = config.getoption('--reportportal')
+
+    # Registering custom markers to supress warnings
+    config.addinivalue_line("markers", "GUI: mark a test as part of the GUI regression suite.")
+    config.addinivalue_line("markers", "API: mark a test as part of the GUI regression suite.")
+    config.addinivalue_line("markers", "MOBILE: mark a test as part of the GUI regression suite.")
+
+
+@pytest.fixture(scope="session")
+def base_url(request):
+    "pytest fixture for base url"
+    try:
+        return request.config.getoption("--app_url")
+
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
